partis.schema\_meta package
===========================

.. automodule:: partis.schema_meta
   :members:
   :show-inheritance:
   :private-members:

Submodules
----------

.. toctree::
   :maxdepth: 2

   partis.schema_meta.base
   partis.schema_meta.eval
   partis.schema_meta.prim
   partis.schema_meta.property
   partis.schema_meta.schema
   partis.schema_meta.struct
   partis.schema_meta.valued
